Πιστοποιητικά | OiRA
Description: Ανάλογα με την προσέγγιση που εφάρμοσε ο εθνικός εταίρος/υπεύθυνος ανάπτυξης του εργαλείου OiRA, ενδέχεται να είναι δυνατή η απόκτηση πιστοποιητικού για την εκτίμηση των κινδύνων που έχετε εκπονήσει. Για περισσότερες λεπτομέρειες σχετικά με τα πλεονεκτήματα που παρέχουν τα εν λόγω πιστοποιητικά, επικοινωνήστε με τον εθνικό σας εταίρο του εργαλείου OiRA.

Θέματα

# Πιστοποιητικά

Ανάλογα με την προσέγγιση που εφάρμοσε ο εθνικός εταίρος/υπεύθυνος ανάπτυξης του εργαλείου OiRA, ενδέχεται να είναι δυνατή η απόκτηση πιστοποιητικού για την εκτίμηση των κινδύνων που έχετε εκπονήσει. Για περισσότερες λεπτομέρειες σχετικά με τα πλεονεκτήματα που παρέχουν τα εν λόγω πιστοποιητικά, επικοινωνήστε με τον εθνικό σας εταίρο του εργαλείου OiRA.

Πώς να αποκτήσετε το πιστοποιητικό

## Εκπονήστε πλήρη εκτίμηση των κινδύνων

Ενόσω εκπονείτε τη μελέτη εκτίμησης των κινδύνων, το εργαλείο OiRA καταγράφει την πρόοδό σας. Μόλις ολοκληρώσετε την εκτίμηση διάφορων κινδύνων, το εργαλείο σας ενημερώνει σχετικά με τη δυνατότητα να αποκτήσετε ένα πιστοποιητικό ολοκλήρωσης της εκτίμησης των κινδύνων που έχετε εκπονήσει. Κάθε εθνικός εταίρος/υπεύθυνος ανάπτυξης εργαλείου OiRA καθορίζει το όριο (υπό μορφή ποσοστού επί τοις εκατό) βάσει του οποίου προσδιορίζεται η πληρότητα της εκτίμησης των κινδύνων. Το πιστοποιητικό είναι διαθέσιμο κάνοντας «κλικ» στην επιλογή «Κατάσταση» στο μενού που βρίσκεται στην αριστερή πλευρά της οθόνης.

Η σελίδα που αφορά την κατάσταση δείχνει ότι το πιστοποιητικό είναι διαθέσιμο.

## Διαβάστε και δημοσιεύστε το πιστοποιητικό σας

Μόλις κάνετε «κλικ» στο «Ανάγνωση πιστοποιητικού», θα κληθείτε να εισάγετε το όνομα της επιχείρησης που θα εμφανίζεται στο πιστοποιητικό. Ανάλογα με τις εθνικές ρυθμίσεις, ενδέχεται να κληθείτε να εισαγάγετε και άλλα δεδομένα προκειμένου να διασφαλισθεί ότι το πιστοποιητικό παρέχει όλες τις αναγκαίες πληροφορίες.

Εισαγωγή όλων των αναγκαίων πληροφοριών για το πιστοποιητικό.

Αν κάνετε «κλικ» στο τετραγωνίδιο «Δημοσιοποίηση», θα εμφανιστεί ένας μοναδικός σύνδεσμος (URL) που οδηγεί στο πιστοποιητικό σας. Αντιγράψτε τον εν λόγω σύνδεσμο και διαβιβάστε τον στους ενδιαφερόμενους ως απόδειξη ότι έχετε διενεργήσει εκτίμηση κινδύνων.

Σημείωση: Μόνο τα δεδομένα που εμφανίζονται σ’ αυτή τη σελίδα θα δημοσιοποιηθούν. Ο σύνδεσμος δεν είναι διαθέσιμος μέσω του μενού του διαδικτυακού τόπου του εργαλείου OiRA — αφορά αποκλειστικά εσάς. Ωστόσο, θεωρητικά, οποιοσδήποτε πλοηγείται στο διαδίκτυο θα μπορούσε να δει το πιστοποιητικό που δημιουργήσατε!

Το πιστοποιητικό δείχνει μόνον ότι έχετε δώσει απαντήσεις για ορισμένους από τους κινδύνους που προτείνονται με το εργαλείο εκτίμησης κινδύνων, όμως δεν παρέχει καμία άλλη πληροφορία. Εκτός από εσάς, κανείς άλλος δεν μπορεί να δεί τις συγκεκριμένες απαντήσεις στην εκτίμηση κινδύνων που δίνονται κατά τη συμπλήρωση του εργαλείου OiRA.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More